Scikit-cycling
==============

.. image:: https://travis-ci.org/scikit-cycling/scikit-cycling.svg?branch=master
    :target: https://travis-ci.org/scikit-cycling/scikit-cycling

.. image:: https://ci.appveyor.com/api/projects/status/f2mvtb9y1mcy99vg?svg=true
    :target: https://ci.appveyor.com/project/glemaitre/scikit-cycling

.. image:: https://readthedocs.org/projects/scikit-cycling/badge/?version=latest
    :target: http://scikit-cycling.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://codecov.io/gh/scikit-cycling/scikit-cycling/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/scikit-cycling/scikit-cycling

.. image:: https://badges.gitter.im/Join%20Chat.svg
  :target: https://gitter.im/scikit-cycling/Lobby?utm_source=share-link&utm_medium=link&utm_cam

Installation
------------

Dependencies
~~~~~~~~~~~~

Scikit-cycling requires:

* scipy
* numpy
* pandas
* six
* fit-parse
* joblib
* scikit-learn


Installation
~~~~~~~~~~~~

You can install the package by cloning the source::

  git clone https://github.com/scikit-cycling/scikit-cycling.git
  cd scikit-cycling
  pip install .

This is also possible to directly install through pip::

  pip install git+https://github.com/scikit-cycling/scikit-cycling.git
